<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="相机ID" prop="cameraId">
        <el-input
          v-model="queryParams.cameraId"
          placeholder="请输入相机ID"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="标定名称" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入标定名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['camera:calibration:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['camera:calibration:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['camera:calibration:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['camera:calibration:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="calibrationList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="相机ID" align="center" prop="cameraId">

      </el-table-column>
      <el-table-column label="标定名称" align="center" prop="name">

      </el-table-column>
      <el-table-column label="目标经度" align="center" prop="targetLongitude">

      </el-table-column>
      <el-table-column label="目标纬度" align="center" prop="targetLatitude">

      </el-table-column>
      <el-table-column label="水平角" align="center" prop="pan">

      </el-table-column>
      <el-table-column label="俯仰角" align="center" prop="tilt">

      </el-table-column>
      <el-table-column label="焦距" align="center" prop="zoom">

      </el-table-column>
      <el-table-column label="水平角差" align="center" prop="panDiff">
      </el-table-column>
      <el-table-column label="俯仰角差" align="center" prop="tiltDiff">
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['camera:calibration:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['camera:calibration:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改光电标定对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
<!--        <el-form-item label="ID" prop="id">-->
<!--          <el-input v-model="form.id" placeholder="请输入ID" />-->
<!--        </el-form-item>-->
        <el-form-item label="相机ID" prop="cameraId">
          <el-input v-model="form.cameraId" placeholder="请输入相机ID" />
        </el-form-item>
        <el-form-item label="标定名称" prop="name">
          <el-input v-model="form.name" placeholder="请输入标定名称" />
        </el-form-item>
        <el-form-item label="目标经度" prop="targetLongitude">
          <el-input v-model="form.targetLongitude" placeholder="请输入目标经度" />
        </el-form-item>
        <el-form-item label="目标纬度" prop="targetLatitude">
          <el-input v-model="form.targetLatitude" placeholder="请输入目标纬度" />
        </el-form-item>
        <el-form-item label="水平角" prop="pan">
          <el-input v-model="form.pan" placeholder="请输入水平角度" />
        </el-form-item>
        <el-form-item label="俯仰角" prop="tilt">
          <el-input v-model="form.tilt" placeholder="请输入俯仰角度" />
        </el-form-item>
        <el-form-item label="焦距" prop="zoom">
          <el-input v-model="form.zoom" placeholder="请输入变倍" />
        </el-form-item>
        <el-form-item label="水平差" prop="panDiff">
          <el-input v-model="form.panDiff" placeholder="请输入水平角差值" />
        </el-form-item>
        <el-form-item label="俯仰差" prop="tiltDiff">
          <el-input v-model="form.tiltDiff" placeholder="请输入俯仰角差值" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listCalibration, getCalibration, delCalibration, addCalibration, updateCalibration } from "@/api/device/calibration";

export default {
  name: "Calibration",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 光电标定表格数据
      calibrationList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        cameraId: null,
        name: null,
        targetLongitude: null,
        targetLatitude: null,
        pan: null,
        tilt: null,
        zoom: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询光电标定列表 */
    getList() {
      this.loading = true;
      listCalibration(this.queryParams).then(response => {
        this.calibrationList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        cameraId: null,
        name: null,
        targetLongitude: null,
        targetLatitude: null,
        pan: null,
        tilt: null,
        zoom: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加光电标定";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getCalibration(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改光电标定";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateCalibration(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addCalibration(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除光电标定编号为"' + ids + '"的数据项？').then(function() {
        return delCalibration(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('camera/calibration/export', {
        ...this.queryParams
      }, `calibration_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
